Nongrid Trace Rest API — Rucio 1.2 documentation

# Nongrid Trace Rest API

Overview

Resource | Operation | Description
--- | --- | ---
XAODTrace | POST /nongrid_traces/ | Send XAOD trace.

Details

`POST` `/nongrid_traces/`

  Trace endpoint used by the XAOD framework to post data access information.

  Request JSON Object:
  | payload (dict) – Dictionary contain the trace information.
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json data. 500 Internal Server Error – Internal Error.